==> haskell-http-conduit-2.3.7.1-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.3.7.1
id: http-conduit-2.3.7.1-AjH5i0QCDIaDVuWIrrtOt7
key: http-conduit-2.3.7.1-AjH5i0QCDIaDVuWIrrtOt7
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
abi: 733f64517e930c29676582daec29824a
exposed: True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-conduit-2.3.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-conduit-2.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-conduit-2.3.7.1
hs-libraries: HShttp-conduit-2.3.7.1-AjH5i0QCDIaDVuWIrrtOt7
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-3gq47figCcD3FXjYab6brY
    conduit-extra-1.3.4-FPFHTkTRnzEHHWVLrWdK4T
    http-client-0.6.4-1ZFfhHOFZM7LvAxodh0J00
    http-client-tls-0.3.5.3-IENmtIJRh8f8yM5X1HdjRQ
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5 mtl-2.2.2
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.7.1-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.3.7.1
id: http-conduit-2.3.7.1-7C6Yl9aU2q0G8aSce4JTCz
key: http-conduit-2.3.7.1-7C6Yl9aU2q0G8aSce4JTCz
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
abi: 6e794c4d05c6ebe78e886320de6754e1
exposed: True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-conduit-2.3.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-conduit-2.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-conduit-2.3.7.1
hs-libraries: HShttp-conduit-2.3.7.1-7C6Yl9aU2q0G8aSce4JTCz
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-3gq47figCcD3FXjYab6brY
    conduit-extra-1.3.4-FPFHTkTRnzEHHWVLrWdK4T
    http-client-0.6.4-1ZFfhHOFZM7LvAxodh0J00
    http-client-tls-0.3.5.3-IENmtIJRh8f8yM5X1HdjRQ
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5 mtl-2.2.2
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
